import { Injectable } from '@angular/core';
import { TranslateService } from '@ngx-translate/core';
import { fromEvent, Subject } from 'rxjs';
import { BrowserStorageService } from '../browser-storage/browser-storage.service';

export class WindowSize {
  isMobile: boolean;

  constructor(
    public width: number,
    public height: number,
  ) {
    this.isMobile = this.width <= 700;
  }

  update() {
    this.width = window.innerWidth;
    this.height = window.innerHeight;
  }

  static generate() {
    return new WindowSize(window.innerWidth, window.innerHeight);
  }
}

@Injectable()
export class AppService {
  private lang = 'en';
  private defaultLang = 'en';
  langChange = new Subject<string>();
  size: WindowSize;
  sizeChange = new Subject<WindowSize>();

  constructor(
    browserStorageService: BrowserStorageService,
    private translate: TranslateService,
  ) {
    this.langChange.subscribe(lang => {
      this.lang = lang;
      browserStorageService.setItem('language', lang);
    });
    this.sizeChange.subscribe(size => this.size = size);
    this.sizeChange.next(WindowSize.generate());
    let lang = browserStorageService.getItem('language');
    if (!lang) {
      lang = this.defaultLang;
    }
    this.translate.setDefaultLang(this.defaultLang);
    this.changeLang(lang);
    fromEvent(window, 'resize').subscribe(e => {
      this.sizeChange.next(WindowSize.generate());
    })
  }

  changeLang(lang: string) {
    if (lang !== this.lang) {
      this.translate.use(lang);
      this.langChange.next(lang);
    }
  }

  getLang() {
    return this.lang;
  }

  getLangs() {
    return [
      'pl',
      'en',
    ];
  }
}
